==> haskell-gi-gobject-debug-2.0.30-134-x86_64.pkg.tar.zst: usr/src/debug/haskell-gi-gobject/gi-gobject-2.0.30/GI/GObject/Objects/ParamSpecUnichar.hs <==
{-# LANGUAGE TypeApplications #-}


-- | Copyright  : Will Thompson and Iñaki García Etxebarria
-- License    : LGPL-2.1
-- Maintainer : Iñaki García Etxebarria
-- 
-- A t'GI.GObject.Objects.ParamSpec.ParamSpec' derived structure that contains the meta data for unichar (unsigned integer) properties.

#if (MIN_VERSION_haskell_gi_overloading(1,0,0) && !defined(__HADDOCK_VERSION__))
#define ENABLE_OVERLOADING
#endif

module GI.GObject.Objects.ParamSpecUnichar
    ( 

-- * Exported types
    ParamSpecUnichar(..)                    ,
    IsParamSpecUnichar                      ,
    toParamSpecUnichar                      ,


 -- * Methods
-- | 
-- 
--  === __Click to display all available methods, including inherited ones__
-- ==== Methods
-- [sink]("GI.GObject.Objects.ParamSpec#g:method:sink"), [stealQdata]("GI.GObject.Objects.ParamSpec#g:method:stealQdata").
-- 
-- ==== Getters
-- [getBlurb]("GI.GObject.Objects.ParamSpec#g:method:getBlurb"), [getDefaultValue]("GI.GObject.Objects.ParamSpec#g:method:getDefaultValue"), [getName]("GI.GObject.Objects.ParamSpec#g:method:getName"), [getNameQuark]("GI.GObject.Objects.ParamSpec#g:method:getNameQuark"), [getNick]("GI.GObject.Objects.ParamSpec#g:method:getNick"), [getQdata]("GI.GObject.Objects.ParamSpec#g:method:getQdata"), [getRedirectTarget]("GI.GObject.Objects.ParamSpec#g:method:getRedirectTarget").
-- 
-- ==== Setters
-- [setQdata]("GI.GObject.Objects.ParamSpec#g:method:setQdata").

#if defined(ENABLE_OVERLOADING)
    ResolveParamSpecUnicharMethod           ,
#endif



    ) where

import Data.GI.Base.ShortPrelude
import qualified Data.GI.Base.ShortPrelude as SP
import qualified Data.GI.Base.Overloading as O
import qualified Prelude as P

import qualified Data.GI.Base.Attributes as GI.Attributes
import qualified Data.GI.Base.BasicTypes as B.Types
import qualified Data.GI.Base.ManagedPtr as B.ManagedPtr
import qualified Data.GI.Base.GArray as B.GArray
import qualified Data.GI.Base.GClosure as B.GClosure
import qualified Data.GI.Base.GError as B.GError
import qualified Data.GI.Base.GHashTable as B.GHT
import qualified Data.GI.Base.GVariant as B.GVariant
import qualified Data.GI.Base.GValue as B.GValue
import qualified Data.GI.Base.GParamSpec as B.GParamSpec
import qualified Data.GI.Base.CallStack as B.CallStack
import qualified Data.GI.Base.Properties as B.Properties
import qualified Data.GI.Base.Signals as B.Signals
import qualified Control.Monad.IO.Class as MIO
import qualified Data.Coerce as Coerce
import qualified Data.Text as T
import qualified Data.Kind as DK
import qualified Data.ByteString.Char8 as B
import qualified Data.Map as Map
import qualified Foreign.Ptr as FP
import qualified GHC.OverloadedLabels as OL
import qualified GHC.Records as R
import qualified Data.Word as DW
import qualified Data.Int as DI
import qualified System.Posix.Types as SPT
import qualified Foreign.C.Types as FCT

-- Workaround for https://gitlab.haskell.org/ghc/ghc/-/issues/23392
#if MIN_VERSION_base(4,18,0)
import {-# SOURCE #-} qualified GI.GObject.Objects.ParamSpec as GObject.ParamSpec

#else
import {-# SOURCE #-} qualified GI.GObject.Objects.ParamSpec as GObject.ParamSpec

#endif

-- | Memory-managed wrapper type.
newtype ParamSpecUnichar = ParamSpecUnichar (SP.ManagedPtr ParamSpecUnichar)
    deriving (Eq)

instance SP.ManagedPtrNewtype ParamSpecUnichar where
    toManagedPtr (ParamSpecUnichar p) = p

foreign import ccall "haskell_gi_pspec_type_init_ParamSpecUnichar"
    c_haskell_gi_pspec_type_init_ParamSpecUnichar :: IO B.Types.GType

instance B.Types.TypedObject ParamSpecUnichar where
    glibType = c_haskell_gi_pspec_type_init_ParamSpecUnichar

-- | Type class for types which can be safely cast to `ParamSpecUnichar`, for instance with `toParamSpecUnichar`.
class (SP.BoxedPtr o, SP.TypedObject o, O.IsDescendantOf ParamSpecUnichar o) => IsParamSpecUnichar o
instance (SP.BoxedPtr o, SP.TypedObject o, O.IsDescendantOf ParamSpecUnichar o) => IsParamSpecUnichar o

instance O.HasParentTypes ParamSpecUnichar
type instance O.ParentTypes ParamSpecUnichar = '[GObject.ParamSpec.ParamSpec]

-- | Cast to `ParamSpecUnichar`, for types for which this is known to be safe. For general casts, use `Data.GI.Base.ManagedPtr.castTo`.
toParamSpecUnichar :: (MIO.MonadIO m, IsParamSpecUnichar o) => o -> m ParamSpecUnichar
toParamSpecUnichar = MIO.liftIO . B.ManagedPtr.unsafeCastTo ParamSpecUnichar

--- XXX Missing getter and/or setter, so no GValue instance could be generated.
#if defined(ENABLE_OVERLOADING)
type family ResolveParamSpecUnicharMethod (t :: Symbol) (o :: DK.Type) :: DK.Type where
    ResolveParamSpecUnicharMethod "sink" o = GObject.ParamSpec.ParamSpecSinkMethodInfo
    ResolveParamSpecUnicharMethod "stealQdata" o = GObject.ParamSpec.ParamSpecStealQdataMethodInfo
    ResolveParamSpecUnicharMethod "getBlurb" o = GObject.ParamSpec.ParamSpecGetBlurbMethodInfo
    ResolveParamSpecUnicharMethod "getDefaultValue" o = GObject.ParamSpec.ParamSpecGetDefaultValueMethodInfo
    ResolveParamSpecUnicharMethod "getName" o = GObject.ParamSpec.ParamSpecGetNameMethodInfo
    ResolveParamSpecUnicharMethod "getNameQuark" o = GObject.ParamSpec.ParamSpecGetNameQuarkMethodInfo
    ResolveParamSpecUnicharMethod "getNick" o = GObject.ParamSpec.ParamSpecGetNickMethodInfo
    ResolveParamSpecUnicharMethod "getQdata" o = GObject.ParamSpec.ParamSpecGetQdataMethodInfo
    ResolveParamSpecUnicharMethod "getRedirectTarget" o = GObject.ParamSpec.ParamSpecGetRedirectTargetMethodInfo
    ResolveParamSpecUnicharMethod "setQdata" o = GObject.ParamSpec.ParamSpecSetQdataMethodInfo
    ResolveParamSpecUnicharMethod l o = O.MethodResolutionFailed l o

instance (info ~ ResolveParamSpecUnicharMethod t ParamSpecUnichar, O.OverloadedMethod info ParamSpecUnichar p) => OL.IsLabel t (ParamSpecUnichar -> p) where
#if MIN_VERSION_base(4,10,0)
    fromLabel = O.overloadedMethod @info
#else
    fromLabel _ = O.overloadedMethod @info
#endif

#if MIN_VERSION_base(4,13,0)
instance (info ~ ResolveParamSpecUnicharMethod t ParamSpecUnichar, O.OverloadedMethod info ParamSpecUnichar p, R.HasField t ParamSpecUnichar p) => R.HasField t ParamSpecUnichar p where
    getField = O.overloadedMethod @info

#endif

instance (info ~ ResolveParamSpecUnicharMethod t ParamSpecUnichar, O.OverloadedMethodInfo info ParamSpecUnichar) => OL.IsLabel t (O.MethodProxy info ParamSpecUnichar) where
#if MIN_VERSION_base(4,10,0)
    fromLabel = O.MethodProxy
#else
    fromLabel _ = O.MethodProxy
#endif

#endif

-- XXX Wrapping a foreign struct/union with no known destructor or size, leak?
instance BoxedPtr ParamSpecUnichar where
    boxedPtrCopy = return
    boxedPtrFree = \_x -> return ()

==> haskell-gi-gobject-debug-2.0.31-70-x86_64.pkg.tar.zst: usr/src/debug/haskell-gi-gobject/gi-gobject-2.0.31/GI/GObject/Objects/ParamSpecUnichar.hs <==
{-# LANGUAGE TypeApplications #-}


-- | Copyright  : Will Thompson and Iñaki García Etxebarria
-- License    : LGPL-2.1
-- Maintainer : Iñaki García Etxebarria
-- 
-- A t'GI.GObject.Objects.ParamSpec.ParamSpec' derived structure that contains the meta data for unichar (unsigned integer) properties.

#if (MIN_VERSION_haskell_gi_overloading(1,0,0) && !defined(__HADDOCK_VERSION__))
#define ENABLE_OVERLOADING
#endif

module GI.GObject.Objects.ParamSpecUnichar
    ( 

-- * Exported types
    ParamSpecUnichar(..)                    ,
    IsParamSpecUnichar                      ,
    toParamSpecUnichar                      ,


 -- * Methods
-- | 
-- 
--  === __Click to display all available methods, including inherited ones__
-- ==== Methods
-- [sink]("GI.GObject.Objects.ParamSpec#g:method:sink"), [stealQdata]("GI.GObject.Objects.ParamSpec#g:method:stealQdata").
-- 
-- ==== Getters
-- [getBlurb]("GI.GObject.Objects.ParamSpec#g:method:getBlurb"), [getDefaultValue]("GI.GObject.Objects.ParamSpec#g:method:getDefaultValue"), [getName]("GI.GObject.Objects.ParamSpec#g:method:getName"), [getNameQuark]("GI.GObject.Objects.ParamSpec#g:method:getNameQuark"), [getNick]("GI.GObject.Objects.ParamSpec#g:method:getNick"), [getQdata]("GI.GObject.Objects.ParamSpec#g:method:getQdata"), [getRedirectTarget]("GI.GObject.Objects.ParamSpec#g:method:getRedirectTarget").
-- 
-- ==== Setters
-- [setQdata]("GI.GObject.Objects.ParamSpec#g:method:setQdata").

#if defined(ENABLE_OVERLOADING)
    ResolveParamSpecUnicharMethod           ,
#endif



    ) where

import Data.GI.Base.ShortPrelude
import qualified Data.GI.Base.ShortPrelude as SP
import qualified Data.GI.Base.Overloading as O
import qualified Prelude as P

import qualified Data.GI.Base.Attributes as GI.Attributes
import qualified Data.GI.Base.BasicTypes as B.Types
import qualified Data.GI.Base.ManagedPtr as B.ManagedPtr
import qualified Data.GI.Base.GArray as B.GArray
import qualified Data.GI.Base.GClosure as B.GClosure
import qualified Data.GI.Base.GError as B.GError
import qualified Data.GI.Base.GHashTable as B.GHT
import qualified Data.GI.Base.GVariant as B.GVariant
import qualified Data.GI.Base.GValue as B.GValue
import qualified Data.GI.Base.GParamSpec as B.GParamSpec
import qualified Data.GI.Base.CallStack as B.CallStack
import qualified Data.GI.Base.Properties as B.Properties
import qualified Data.GI.Base.Signals as B.Signals
import qualified Control.Monad.IO.Class as MIO
import qualified Data.Coerce as Coerce
import qualified Data.Text as T
import qualified Data.Kind as DK
import qualified Data.ByteString.Char8 as B
import qualified Data.Map as Map
import qualified Foreign.Ptr as FP
import qualified GHC.OverloadedLabels as OL
import qualified GHC.Records as R
import qualified Data.Word as DW
import qualified Data.Int as DI
import qualified System.Posix.Types as SPT
import qualified Foreign.C.Types as FCT

-- Workaround for https://gitlab.haskell.org/ghc/ghc/-/issues/23392
#if MIN_VERSION_base(4,18,0)
import {-# SOURCE #-} qualified GI.GObject.Objects.ParamSpec as GObject.ParamSpec

#else
import {-# SOURCE #-} qualified GI.GObject.Objects.ParamSpec as GObject.ParamSpec

#endif

-- | Memory-managed wrapper type.
newtype ParamSpecUnichar = ParamSpecUnichar (SP.ManagedPtr ParamSpecUnichar)
    deriving (Eq)

instance SP.ManagedPtrNewtype ParamSpecUnichar where
    toManagedPtr (ParamSpecUnichar p) = p

foreign import ccall "haskell_gi_pspec_type_init_ParamSpecUnichar"
    c_haskell_gi_pspec_type_init_ParamSpecUnichar :: IO B.Types.GType

instance B.Types.TypedObject ParamSpecUnichar where
    glibType = c_haskell_gi_pspec_type_init_ParamSpecUnichar

-- | Type class for types which can be safely cast to t'ParamSpecUnichar', for instance with `toParamSpecUnichar`.
class (SP.BoxedPtr o, SP.TypedObject o, O.IsDescendantOf ParamSpecUnichar o) => IsParamSpecUnichar o
instance (SP.BoxedPtr o, SP.TypedObject o, O.IsDescendantOf ParamSpecUnichar o) => IsParamSpecUnichar o

instance O.HasParentTypes ParamSpecUnichar
type instance O.ParentTypes ParamSpecUnichar = '[GObject.ParamSpec.ParamSpec]

-- | Cast to t'ParamSpecUnichar', for types for which this is known to be safe. For general casts, use 'Data.GI.Base.ManagedPtr.castTo'.
toParamSpecUnichar :: (MIO.MonadIO m, IsParamSpecUnichar o) => o -> m ParamSpecUnichar
toParamSpecUnichar = MIO.liftIO . B.ManagedPtr.unsafeCastTo ParamSpecUnichar

--- XXX Missing getter and/or setter, so no GValue instance could be generated.
#if defined(ENABLE_OVERLOADING)
type family ResolveParamSpecUnicharMethod (t :: Symbol) (o :: DK.Type) :: DK.Type where
    ResolveParamSpecUnicharMethod "sink" o = GObject.ParamSpec.ParamSpecSinkMethodInfo
    ResolveParamSpecUnicharMethod "stealQdata" o = GObject.ParamSpec.ParamSpecStealQdataMethodInfo
    ResolveParamSpecUnicharMethod "getBlurb" o = GObject.ParamSpec.ParamSpecGetBlurbMethodInfo
    ResolveParamSpecUnicharMethod "getDefaultValue" o = GObject.ParamSpec.ParamSpecGetDefaultValueMethodInfo
    ResolveParamSpecUnicharMethod "getName" o = GObject.ParamSpec.ParamSpecGetNameMethodInfo
    ResolveParamSpecUnicharMethod "getNameQuark" o = GObject.ParamSpec.ParamSpecGetNameQuarkMethodInfo
    ResolveParamSpecUnicharMethod "getNick" o = GObject.ParamSpec.ParamSpecGetNickMethodInfo
    ResolveParamSpecUnicharMethod "getQdata" o = GObject.ParamSpec.ParamSpecGetQdataMethodInfo
    ResolveParamSpecUnicharMethod "getRedirectTarget" o = GObject.ParamSpec.ParamSpecGetRedirectTargetMethodInfo
    ResolveParamSpecUnicharMethod "setQdata" o = GObject.ParamSpec.ParamSpecSetQdataMethodInfo
    ResolveParamSpecUnicharMethod l o = O.MethodResolutionFailed l o

instance (info ~ ResolveParamSpecUnicharMethod t ParamSpecUnichar, O.OverloadedMethod info ParamSpecUnichar p) => OL.IsLabel t (ParamSpecUnichar -> p) where
#if MIN_VERSION_base(4,10,0)
    fromLabel = O.overloadedMethod @info
#else
    fromLabel _ = O.overloadedMethod @info
#endif

#if MIN_VERSION_base(4,13,0)
instance (info ~ ResolveParamSpecUnicharMethod t ParamSpecUnichar, O.OverloadedMethod info ParamSpecUnichar p, R.HasField t ParamSpecUnichar p) => R.HasField t ParamSpecUnichar p where
    getField = O.overloadedMethod @info

#endif

instance (info ~ ResolveParamSpecUnicharMethod t ParamSpecUnichar, O.OverloadedMethodInfo info ParamSpecUnichar) => OL.IsLabel t (O.MethodProxy info ParamSpecUnichar) where
#if MIN_VERSION_base(4,10,0)
    fromLabel = O.MethodProxy
#else
    fromLabel _ = O.MethodProxy
#endif

#endif

-- XXX Wrapping a foreign struct/union with no known destructor or size, leak?
instance BoxedPtr ParamSpecUnichar where
    boxedPtrCopy = return
    boxedPtrFree = \_x -> return ()
